.. :changelog:

History
-------

0.2.0 (2015-04-21)
------------------

* Local math operations added to Raster class, intergrated with Pygeoprocessing

0.1.1 (2015-03-15)
---------------------

* Raster, TestRaster, and RasterFactory classes added

0.1.0 (2015-01-21)
---------------------

* First release on PyPI.
